package hybridchill.eclipse.qpscanner.popup.actions;

import hybridchill.eclipse.qpscanner.Activator;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IObjectActionDelegate;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;

import com.bdaum.overlayPages.FieldEditorOverlayPage;



public class ScanAction implements IObjectActionDelegate, IViewActionDelegate
{


	private IResource selectedResource;



	public void run(IAction action)
	{

		/*
			INFO:
			Grab the user's preferences.
			Compile the Url from the ScannerUrl preference, the selected resource, and the user preferences.
			Send the final Url for loading.
		*/

		IPreferenceStore UserPrefs = Activator.getDefault().getPreferenceStore();

		String Url = UserPrefs.getString("ScannerUrl")
			.concat( "&startingdir=" )
			.concat( selectedResource.getLocation().toString() )
			.concat( convertPrefsToQuerystring( UserPrefs , "&" , "=" ) );
		
		loadUrl( "QueryParamScanner" , Url );

	}


	private String convertPrefsToQuerystring( IPreferenceStore UserPrefs , String Delimiter , String Assigner )
	{

		try
		{
			String UrlParams = ""; 
		
    		// TODO: MINOR: CHECK: There should be a way to get this from UserPrefs variable?
    		String[] PrefList =
				{ "OutputFormat"
				, "RequestTimeout"
				// , "StartingDir" - Excluded since defined by selection.
				, "recurse"
				, "Exclusions"
				, "scanOrderBy"
				, "scanQoQ"
				, "scanBuiltInFunc"
				, "showScopeInfo"
				, "highlightClientScopes"
				, "ClientScopes"
				};


    		for (String PrefId : PrefList)
            {
				UrlParams = UrlParams
				.concat( Delimiter )
				.concat( PrefId )
				.concat( Assigner )
				.concat( readPreference( UserPrefs , PrefId ) )
				;
            }

    		return UrlParams;
		}
		catch( Exception e )
		{
			showError( e , "An unknown error occurrest whilst reading preferences." );
			
			return "ERROR";
		}
	}



	private void loadUrl( String BrowserId , String Url )
	{

    	try
    	{
    		URL url = new URL( Url );

    		try
    		{

    			PlatformUI.getWorkbench().getBrowserSupport()
    				.createBrowser( BrowserId )
    				.openURL( url );

    		}
    		catch( PartInitException e)
    		{
    			showError( e , "There was a PartInitException" );
    		}

    	}
    	catch( MalformedURLException e )
    	{
    		showError( e , "There was a MalformedURLException for URL '".concat(Url).concat("'.") );
    	}

	}

	

	private void showError( Exception e , String Msg )
	{
		Shell shell = new Shell();

		MessageDialog.openError
			( shell
			, "QueryParam Scanner Eclipse Plug-in"
			, Msg
			);
	}


/*
	private void msg( String Msg )
	{
		Shell shell = new Shell();

		MessageDialog.openInformation
			( shell
			, "QueryParam Scanner Eclipse Plug-in"
			, Msg
			);
	}
*/
	



	public void selectionChanged(IAction action, ISelection selection)
	{
		selectedResource = (IResource) ((StructuredSelection) selection).getFirstElement();
	}



	public void init(IViewPart view)
	{
		
	}



	/**
	* @see IObjectActionDelegate#setActivePart(IAction, IWorkbenchPart)
	*/
	public void setActivePart(IAction action, IWorkbenchPart targetPart)
	{
	}

	
	
	
	
	public String readPreference( IPreferenceStore UserPrefs , String key )
	{
		return getOverlayedPreferenceValue
			( UserPrefs
			, selectedResource
			, "qpScanner_eclipse.preferences.defaultPreferences"
			, key
			);
	}
	
	
	/*
		INFO:
		Functions from com.bdaum.overlayPages ( http://www.eclipse.org/articles/Article-Mutatis-mutandis/overlay-pages.html )
		Used for reading preferences/properties.
	*/
	
	public static String getOverlayedPreferenceValue( IPreferenceStore store , IResource resource , String pageId , String key )
	{
		IProject project = resource.getProject();
		String value = null;

		if (useProjectSettings(project , pageId))
		{
			value = getProperty( resource , pageId , key );
		}

		if (value != null) return value;
		
		return store.getString( key );
	}



	private static boolean useProjectSettings(IResource resource, String pageId)
	{
		String use = getProperty( resource , pageId , FieldEditorOverlayPage.USEPROJECTSETTINGS );
		return "true".equals(use);
	}



	private static String getProperty(IResource resource, String pageId, String key)
	{
		try
		{
			return resource.getPersistentProperty(new QualifiedName(pageId, key));
		}
		catch (CoreException e)
		{
			// do nothing
		}
		return null;
	}
	
	
}
