package hybridchill.eclipse.qpscanner.preferences;

import hybridchill.eclipse.qpscanner.Activator;

import org.eclipse.jface.preference.*;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.eclipse.ui.IWorkbench;

import com.bdaum.overlayPages.FieldEditorOverlayPage;



/**
 * This class represents a preference page that is contributed to the
 * Preferences dialog. By subclassing <samp>FieldEditorPreferencePage</samp>,
 * we can use the field support built into JFace that allows us to create a page
 * that is small and knows how to save, restore and apply itself.
 * <p>
 * This page is used to modify preferences only. They are stored in the
 * preference store that belongs to the main plug-in class. That way,
 * preferences can be accessed directly via the preference store.
 */

public class QpScannerPreferencePage
	extends FieldEditorOverlayPage
	implements IWorkbenchPreferencePage
{


	public QpScannerPreferencePage()
	{
		super(GRID);
		setPreferenceStore(Activator.getDefault().getPreferenceStore());
		setDescription("Default configuration for QueryParam Scanner");
	}


	protected String getPageId()
	{
			return "qpScanner_eclipse.preferences.defaultPreferences";
	}
	

	/**
	 * Creates the field editors. Field editors are abstractions of the common
	 * GUI blocks needed to manipulate various types of preferences. Each field
	 * editor knows how to save and restore itself.
	 */
	public void createFieldEditors()
	{
		addField
			( new StringFieldEditor
				( PreferenceConstants.P_URL
				, "&Url Root"
				, getFieldEditorParent()
				)
			);

		addField
			( new BooleanFieldEditor
				( PreferenceConstants.P_RECURSE
				, "&Recurse through sub-directories"
				, getFieldEditorParent()
				)
			);

		addField
    		( new StringFieldEditor
    			( PreferenceConstants.P_REQUESTTIMEOUT
    			, "Request &Timeout"
    			, getFieldEditorParent()
    			)
    		);

		addField
    		( new BooleanFieldEditor
    			( PreferenceConstants.P_SCANORDERBY
    			, "Scan &ORDER BY"
    			, getFieldEditorParent()
    			)
    		);

		addField
    		( new BooleanFieldEditor
    			( PreferenceConstants.P_SCANQOQ
    			, "Scan &Query of Queries"
    			, getFieldEditorParent()
    			)
		);

		addField
    		( new BooleanFieldEditor
    			( PreferenceConstants.P_SCANBUILTINFUNC
    			, "Scan Built-In &Functions"
    			, getFieldEditorParent()
    			)
    		);

		addField
    		( new BooleanFieldEditor
    			( PreferenceConstants.P_SHOWSCOPEINFO
    			, "Show Scope &Info"
    			, getFieldEditorParent()
    			)
    		);

		addField
    		( new BooleanFieldEditor
    			( PreferenceConstants.P_HIGHLIGHTCLIENTSCOPES
    			, "Highlight &Client Scopes"
    			, getFieldEditorParent()
    			)
    		);

		addField
    		( new StringFieldEditor
    			( PreferenceConstants.P_CLIENTSCOPES
    			, "&Client Scopes"
    			, getFieldEditorParent()
    			)
    		);

		addField
    		( new StringFieldEditor
    			( PreferenceConstants.P_EXCLUSIONS
    			, "&Exclusions"
    			, getFieldEditorParent()
    			)
    		);



		addField
			( new RadioGroupFieldEditor
				( PreferenceConstants.P_OUTPUTFORMAT
				, "O&utput Format"
				, 1
				, new String[][]
					{ { "&HTML", "html" }
					, { "&WDDX", "wddx" }
					, { "&XML",  "xml" }
					}
				, getFieldEditorParent()
				)
			);

	}



	/*
	 * (non-Javadoc)
	 *
	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
	 */
	public void init(IWorkbench workbench)
	{
	}

}